@@ -1,7 +1,7 @@
 /*
  *  Copyright (C) 1999-2002 Bernd Gehrmann
  *                          bernd@mail.berlios.de
- *  Copyright (c) 2003-2004 Christian Loose <christian.loose@hamburg.de>
+ *  Copyright (c) 2003-2008 Christian Loose <christian.loose@kdemail.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,43 +20,46 @@
 
 #include <iostream>
 
-#include <qfileinfo.h>
+#include <QFileInfo>
+
 #include <kaboutdata.h>
 #include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kconfig.h>
 #include <klocale.h>
 #include <kurl.h>
+#include <ktoolinvocation.h>
 
 #include "misc.h"
 #include "cervisiashell.h"
-#include "cvsservice_stub.h"
-#include "annotatedlg.h"
-#include "annotatectl.h"
-#include "logdlg.h"
-#include "resolvedlg.h"
+#include "cvsserviceinterface.h"
+#include "annotatedialog.h"
+#include "annotatecontroller.h"
+#include "logdialog.h"
+#include "resolvedialog.h"
 #include "version.h"
+#include "repositoryinterface.h"
 
-
-static CvsService_stub* StartDCOPService(const QString& directory)
+static OrgKdeCervisiaCvsserviceCvsserviceInterface* StartDBusService(const QString& directory)
 {
-    // start the cvs DCOP service
+    // start the cvs D-Bus service
     QString error;
-    QCString appId;
-    if( KApplication::startServiceByDesktopName("cvsservice", QStringList(),
-                                                &error, &appId) )
+    QString appId;
+    if( KToolInvocation::startServiceByDesktopName("cvsservice", QStringList(),
+                                                &error,&appId)  )
     {
         std::cerr << "Starting cvsservice failed with message: "
-                  << error.latin1() << std::endl;
+                  << error.toLatin1().constData() << std::endl;
         exit(1);
     }
 
-    DCOPRef repository(appId, "CvsRepository");
+    OrgKdeCervisiaRepositoryInterface repository(appId, "/CvsRepository",QDBusConnection::sessionBus());
+    
 
-    repository.call("setWorkingCopy(QString)", directory);
+    repository.setWorkingCopy(directory);
 
     // create a reference to the service
-    return new CvsService_stub(appId, "CvsService");
+    return new OrgKdeCervisiaCvsserviceCvsserviceInterface(appId, "/CvsService",QDBusConnection::sessionBus());
 }
 
 
@@ -65,13 +68,12 @@ static int ShowResolveDialog(const QString& fileName)
     KConfig* config = new KConfig("cervisiapartrc");
 
     ResolveDialog* dlg = new ResolveDialog(*config);
-    kapp->setMainWidget(dlg);
     if( dlg->parseFile(fileName) )
         dlg->show();
     else
         delete dlg;
 
-    int result = kapp->exec();
+    int result = qApp->exec();
 
     delete config;
 
@@ -83,21 +85,20 @@ static int ShowLogDialog(const QString& fileName)
 {
     KConfig* config = new KConfig("cervisiapartrc");
     LogDialog* dlg = new LogDialog(*config);
-    kapp->setMainWidget(dlg);
 
     // get directory for file
     const QFileInfo fi(fileName);
-    QString directory = fi.dirPath(true);
+    QString directory = fi.absolutePath();
 
     // start the cvs DCOP service
-    CvsService_stub* cvsService = StartDCOPService(directory);
+    OrgKdeCervisiaCvsserviceCvsserviceInterface* cvsService = StartDBusService(directory);
 
     if( dlg->parseCvsLog(cvsService, fi.fileName()) )
         dlg->show();
     else
         delete dlg;
 
-    int result = kapp->exec();
+    int result = qApp->exec();
 
     // stop the cvs DCOP service
     cvsService->quit();
@@ -113,21 +114,20 @@ static int ShowAnnotateDialog(const QString& fileName)
 {
     KConfig* config = new KConfig("cervisiapartrc");
     AnnotateDialog* dlg = new AnnotateDialog(*config);
-    kapp->setMainWidget(dlg);
 
     // get directory for file
     const QFileInfo fi(fileName);
-    QString directory = fi.dirPath(true);
+    QString directory = fi.absolutePath();
 
-    // start the cvs DCOP service
-    CvsService_stub* cvsService = StartDCOPService(directory);
+    // start the cvs D-Bus service
+    OrgKdeCervisiaCvsserviceCvsserviceInterface* cvsService = StartDBusService(directory);
 
     AnnotateController ctl(dlg, cvsService);
     ctl.showDialog(fi.fileName());
 
-    int result = kapp->exec();
+    int result = qApp->exec();
 
-    // stop the cvs DCOP service
+    // stop the cvs D-Bus service
     cvsService->quit();
     delete cvsService;
 
@@ -139,32 +139,33 @@ static int ShowAnnotateDialog(const QString& fileName)
 
 extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 {
-    static KCmdLineOptions options[] = {
-        { "+[directory]", I18N_NOOP("The sandbox to be loaded"), 0 },
-        { "resolve <file>", I18N_NOOP("Show resolve dialog for the given file"), 0 },
-        { "log <file>", I18N_NOOP("Show log dialog for the given file"), 0 },
-        { "annotate <file>", I18N_NOOP("Show annotation dialog for the given file"), 0 },
-        KCmdLineLastOption
-    };
-    KAboutData about("cervisia", I18N_NOOP("Cervisia"), CERVISIA_VERSION,
-                     I18N_NOOP("A CVS frontend"), KAboutData::License_GPL,
-                     I18N_NOOP("Copyright (c) 1999-2002 Bernd Gehrmann\n"
-                               "Copyright (c) 2002-2004 the Cervisia authors"), 0,
-                     "http://www.kde.org/apps/cervisia");
+    KAboutData about("cervisia", 0, ki18n("Cervisia"), CERVISIA_VERSION,
+                     ki18n("A CVS frontend"), KAboutData::License_GPL,
+                     ki18n("Copyright (c) 1999-2002 Bernd Gehrmann\n"
+                           "Copyright (c) 2002-2008 the Cervisia authors"), KLocalizedString(),
+                     "http://cervisia.kde.org");
 
-    about.addAuthor("Bernd Gehrmann", I18N_NOOP("Original author and former "
-                    "maintainer"), "bernd@mail.berlios.de", 0);
-    about.addAuthor("Christian Loose", I18N_NOOP("Maintainer"),
-                    "christian.loose@kdemail.net", 0);
-    about.addAuthor("Andr\303\251 W\303\266bbeking", I18N_NOOP("Developer"),
-                    "woebbeking@web.de", 0);
-    about.addAuthor("Carlos Woelz", I18N_NOOP("Documentation"),
-                    "carloswoelz@imap-mail.com", 0);
+    about.addAuthor(ki18n("Bernd Gehrmann"), ki18n("Original author and former "
+                    "maintainer"), "bernd@mail.berlios.de");
+    about.addAuthor(ki18n("Christian Loose"), ki18n("Maintainer"),
+                    "christian.loose@kdemail.net");
+    about.addAuthor(ki18n("Andr\303\251 W\303\266bbeking"), ki18n("Developer"),
+                    "woebbeking@kde.org");
+    about.addAuthor(ki18n("Carlos Woelz"), ki18n("Documentation"),
+                    "carloswoelz@imap-mail.com");
 
-    about.addCredit("Richard Moore", I18N_NOOP("Conversion to KPart"),
-                    "rich@kde.org", 0);
+    about.addCredit(ki18n("Richard Moore"), ki18n("Conversion to KPart"),
+                    "rich@kde.org");
+    about.addCredit(ki18n("Laurent Montel"), ki18n("Conversion to D-Bus"),
+                    "montel@kde.org");
 
     KCmdLineArgs::init(argc, argv, &about);
+
+    KCmdLineOptions options;
+    options.add("+[directory]", ki18n("The sandbox to be loaded"));
+    options.add("resolve <file>", ki18n("Show resolve dialog for the given file"));
+    options.add("log <file>", ki18n("Show log dialog for the given file"));
+    options.add("annotate <file>", ki18n("Show annotation dialog for the given file"));
     KCmdLineArgs::addCmdLineOptions(options);
 
     KApplication app;
@@ -183,7 +184,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
     if( !annotateFile.isEmpty() )
         return ShowAnnotateDialog(annotateFile);
 
-    if ( app.isRestored() ) {
+    if ( app.isSessionRestored() ) {
         RESTORE(CervisiaShell);
     } else {
         CervisiaShell* shell = new CervisiaShell();
@@ -191,14 +192,13 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
         const KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
         if( args->count() )
         {
-            KURL directory = args->url(0);
+            KUrl directory = args->url(0);
             shell->openURL(directory);
         }
         else
             shell->openURL();
 
-        shell->setIcon(app.icon());
-        app.setMainWidget(shell);
+        shell->setWindowIcon(qApp->windowIcon());
         shell->show();
     }
 
