@@ -13,8 +13,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "ast.h"
@@ -117,15 +117,14 @@ QString nodeTypeToString( int type )
 	return "Custom";
     }
 
-    return QString::null;
+    return QString();
 }
 
 
 // ------------------------------------------------------------------------
 AST::AST()
     : m_nodeType( NodeType_Generic ), m_parent( 0 ),
-      m_startLine( 0 ), m_startColumn( 0 ),
-      m_endLine( 0 ), m_endColumn( 0 )
+    m_startPosition(), m_endPosition()
 {
 #ifndef CPPPARSER_NO_CHILDREN
     m_children.setAutoDelete( false );
@@ -140,35 +139,13 @@ AST::~AST()
 #endif
 }
 
-void AST::setStartPosition( int line, int col )
-{
-   m_startLine = line;
-   m_startColumn = col;
-}
+void AST::setStartPosition( Position const& p ) {m_startPosition = p;}
 
-void AST::getStartPosition( int* line, int* col ) const
-{
-    if( line )
-        *line = m_startLine;
+Position const& AST::getStartPosition() const {return m_startPosition;}
 
-    if( col )
-        * col = m_startColumn;
-}
+void AST::setEndPosition( Position const& p ) {m_endPosition = p;}
 
-void AST::setEndPosition( int line, int col )
-{
-   m_endLine = line;
-   m_endColumn = col;
-}
-
-void AST::getEndPosition( int* line, int* col ) const
-{
-    if( line )
-        *line = m_endLine;
-
-    if( col )
-        * col = m_endColumn;
-}
+Position const& AST::getEndPosition() const {return m_endPosition;}
 
 void AST::setParent( AST* parent )
 {
@@ -227,7 +204,7 @@ void NameAST::addClassOrNamespaceName( ClassOrNamespaceNameAST::Node& classOrNam
 QString NameAST::text() const
 {
     if( !m_unqualifiedName.get() )
-        return QString::null;
+        return QString();
 
     QString str;
 
@@ -235,7 +212,7 @@ QString NameAST::text() const
         str += "::";
 
     QStringList l;
-    QPtrListIterator<ClassOrNamespaceNameAST> it( m_classOrNamespaceNameList );
+    Q3PtrListIterator<ClassOrNamespaceNameAST> it( m_classOrNamespaceNameList );
     while( it.current() ){
         str += it.current()->text() + "::";
         ++it;
@@ -293,7 +270,7 @@ void LinkageSpecificationAST::setDeclaration( DeclarationAST::Node& decl )
 // ------------------------------------------------------------------------
 TranslationUnitAST::TranslationUnitAST()
 {
-    //kdDebug(9007) << "++ TranslationUnitAST::TranslationUnitAST()" << endl;
+    //kDebug(9007) << "++ TranslationUnitAST::TranslationUnitAST()";
     m_declarationList.setAutoDelete( true );
 }
 
@@ -410,7 +387,7 @@ QString TemplateArgumentListAST::text() const
 {
     QStringList l;
 
-    QPtrListIterator<AST> it( m_argumentList );
+    Q3PtrListIterator<AST> it( m_argumentList );
     while( it.current() ){
         l.append( it.current()->text() );
 	++it;
@@ -462,7 +439,7 @@ void ClassOrNamespaceNameAST::setTemplateArgumentList( TemplateArgumentListAST::
 QString ClassOrNamespaceNameAST::text() const
 {
     if( !m_name.get() )
-        return QString::null;
+        return QString();
 
     QString str = m_name->text();
     if( m_templateArgumentList.get() )
@@ -493,7 +470,7 @@ QString TypeSpecifierAST::text() const
     QString str;
 
     if( m_cvQualify.get() )
-        str += m_cvQualify->text() + " ";
+        str += m_cvQualify->text() + ' ';
 
     if( m_name.get() )
         str += m_name->text();
@@ -561,7 +538,7 @@ void ElaboratedTypeSpecifierAST::setKind( AST::Node& kind )
 QString ElaboratedTypeSpecifierAST::text() const
 {
     if( m_kind.get() )
-        return m_kind->text() + " " + TypeSpecifierAST::text();
+        return m_kind->text() + ' ' + TypeSpecifierAST::text();
 
     return TypeSpecifierAST::text();
 }
@@ -964,7 +941,7 @@ QString ParameterDeclarationAST::text() const
 {
     QString str;
     if( m_typeSpec.get() )
-        str += m_typeSpec->text() + " ";
+        str += m_typeSpec->text() + ' ';
 
     if( m_declarator.get() )
         str += m_declarator->text();
@@ -994,7 +971,7 @@ QString ParameterDeclarationListAST::text() const
 {
     QStringList l;
 
-    QPtrListIterator<ParameterDeclarationAST> it( m_parameterList );
+    Q3PtrListIterator<ParameterDeclarationAST> it( m_parameterList );
     while( it.current() ){
         l.append( it.current()->text() );
 	++it;
@@ -1054,7 +1031,7 @@ QString GroupAST::text() const
 {
     QStringList l;
 
-    QPtrListIterator<AST> it( m_nodeList );
+    Q3PtrListIterator<AST> it( m_nodeList );
     while( it.current() ){
         l.append( it.current()->text() );
 	++it;
@@ -1082,7 +1059,7 @@ QString AccessDeclarationAST::text() const
 {
     QStringList l;
 
-    QPtrListIterator<AST> it( m_accessList );
+    Q3PtrListIterator<AST> it( m_accessList );
     while( it.current() ){
         l.append( it.current()->text() );
 	++it;
