@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -13,32 +13,44 @@
 #include "classgenpage.h"
 
 // qt includes
-#include <qlayout.h>
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qbuttongroup.h>
-#include <qmultilineedit.h>
-#include <qradiobutton.h>
-#include <qcheckbox.h>
+#include <QtGui/QLayout>
+#include <q3groupbox.h>
+#include <QtGui/QLineEdit>
+#include <q3buttongroup.h>
+#include <q3multilineedit.h>
+#include <QtGui/QRadioButton>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLabel>
+#include <QtGui/QVBoxLayout>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QGridLayout>
 
 // kde includes
 #include <klocale.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kcombobox.h>
+#include <klineedit.h>
 
 // my class includes
-#include "../umlobject.h"
-#include "../objectwidget.h"
-#include "../uml.h"
-#include "../umldoc.h"
-#include "../artifact.h"
-#include "../component.h"
-#include "../umlview.h"
-#include "../stereotype.h"
+#include "umlobject.h"
+#include "objectwidget.h"
+#include "uml.h"
+#include "umldoc.h"
+#include "artifact.h"
+#include "component.h"
+#include "umlview.h"
+#include "stereotype.h"
+#include "umlpackagelist.h"
+#include "umllistviewitem.h"
+#include "umllistview.h"
+#include "model_utils.h"
+#include "package.h"
+#include "folder.h"
+#include "codeimport/import_utils.h"
 
-ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(parent) {
+ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(parent)
+{
     m_pWidget = 0;
     m_pObject = 0;
     m_pInstanceWidget = 0;
@@ -58,6 +70,8 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(p
         name = i18n("Interface &name:");
     } else if (t == Uml::ot_Component) {
         name = i18n("Component &name:");
+    } else if (t == Uml::ot_Node) {
+        name = i18n("Node &name:");
     } else if (t == Uml::ot_Artifact) {
         name = i18n("Artifact &name:");
     } else if (t == Uml::ot_Enum) {
@@ -67,7 +81,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(p
     } else if (t == Uml::ot_Entity) {
         name = i18n("Entity &name:");
     } else {
-        kWarning() << "creating class gen page for unknown widget type" << endl;
+        uWarning() << "creating class gen page for unknown widget type";
     }
     setMinimumSize(310,330);
     QVBoxLayout * topLayout = new QVBoxLayout(this);
@@ -80,7 +94,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(p
     m_pNameL -> setText(name);
     m_pNameLayout -> addWidget(m_pNameL, 0, 0);
 
-    m_pClassNameLE = new QLineEdit(this);
+    m_pClassNameLE = new KLineEdit(this);
     m_pNameLayout -> addWidget(m_pClassNameLE, 0, 1);
     m_pClassNameLE->setFocus();
     m_pNameL->setBuddy(m_pClassNameLE);
@@ -96,7 +110,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(p
     m_pStereoTypeCB = new KComboBox(true, this);
     m_pNameLayout -> addWidget(m_pStereoTypeCB, 1, 1);
 
-    m_pStereoTypeCB->setCurrentText( o->getStereotype() );
+    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), o->getStereotype() );
     m_pStereoTypeL->setBuddy(m_pStereoTypeCB);
 
     if (t == Uml::ot_Interface || t == Uml::ot_Datatype || t == Uml::ot_Enum) {
@@ -104,15 +118,25 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(p
     }
 
     if (t == Uml::ot_Class || t == Uml::ot_Interface) {
-        m_pPackageL = new QLabel(i18n("&Package name:"), this);
+        m_pPackageL = new QLabel(i18n("Package name:"), this);
         m_pNameLayout -> addWidget(m_pPackageL, 2, 0);
 
-        m_pPackageLE = new QLineEdit(this);
-        m_pNameLayout -> addWidget(m_pPackageLE, 2, 1);
+        m_pPackageCB = new KComboBox(this);
+        m_pPackageCB->setEditable(true);
+        m_pNameLayout -> addWidget(m_pPackageCB, 2, 1);
 
-        m_pPackageLE -> setText(o -> getPackage());
-        m_pPackageLE -> setEnabled(false);
-        m_pPackageL->setBuddy(m_pPackageLE);
+        UMLPackageList packageList = m_pUmldoc->getPackages();
+        foreach( UMLPackage* package, packageList ) {
+            m_pPackageCB->addItem(package->getName());
+        }
+        UMLPackage* parentPackage = o->getUMLPackage();
+
+        // if parent package == NULL
+        // or if the parent package is the Logical View folder
+        if ( parentPackage == NULL || parentPackage== static_cast<UMLPackage*>(m_pUmldoc->getRootFolder(Uml::mt_Logical)))
+            m_pPackageCB->setEditText( QString() );
+        else
+            m_pPackageCB->setEditText(parentPackage->getName());
     }
 
     if (t == Uml::ot_Class || t == Uml::ot_UseCase ) {
@@ -128,19 +152,19 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(p
     }
 
     if (t == Uml::ot_Component) {
-        m_pExecutableCB = new QCheckBox(i18n("&Executable"), this);
+        m_pExecutableCB = new QCheckBox(i18nc("component is executable", "&Executable"), this);
         m_pExecutableCB->setChecked( (static_cast<UMLComponent*>(o))->getExecutable() );
         m_pNameLayout->addWidget( m_pExecutableCB, 3, 0 );
     }
 
     if (t == Uml::ot_Artifact) {
         //setup artifact draw as
-        m_pDrawAsBG = new QButtonGroup(i18n("Draw As"), this);
+        m_pDrawAsBG = new Q3ButtonGroup(i18n("Draw As"), this);
         QHBoxLayout* drawAsLayout = new QHBoxLayout(m_pDrawAsBG);
         drawAsLayout->setMargin(margin);
         m_pDrawAsBG->setExclusive(true);
 
-        m_pDefaultRB = new QRadioButton(i18n("&Default"), m_pDrawAsBG);
+        m_pDefaultRB = new QRadioButton(i18nc("draw as default", "&Default"), m_pDrawAsBG);
         drawAsLayout->addWidget(m_pDefaultRB);
 
         m_pFileRB = new QRadioButton(i18n("&File"), m_pDrawAsBG);
@@ -168,31 +192,32 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(p
     }
 
     //setup scope
-    m_pButtonBG = new QButtonGroup(i18n("Visibility"), this);
+    m_pButtonBG = new Q3ButtonGroup(i18n("Visibility"), this);
     QHBoxLayout * scopeLayout = new QHBoxLayout(m_pButtonBG);
     scopeLayout -> setMargin(margin);
     m_pButtonBG -> setExclusive(true);
 
-    m_pPublicRB = new QRadioButton(i18n("P&ublic"), m_pButtonBG);
+    m_pPublicRB = new QRadioButton(i18nc("public visibility", "P&ublic"), m_pButtonBG);
     scopeLayout -> addWidget(m_pPublicRB);
 
-    m_pPrivateRB = new QRadioButton(i18n("P&rivate"), m_pButtonBG);
+    m_pPrivateRB = new QRadioButton(i18nc("private visibility", "P&rivate"), m_pButtonBG);
     scopeLayout -> addWidget(m_pPrivateRB);
 
-    m_pProtectedRB = new QRadioButton(i18n("Pro&tected"), m_pButtonBG);
+    m_pProtectedRB = new QRadioButton(i18nc("protected visibility", "Pro&tected"), m_pButtonBG);
     scopeLayout -> addWidget(m_pProtectedRB);
     topLayout -> addWidget(m_pButtonBG);
-    
+
     m_pImplementationRB = new QRadioButton(i18n("Imple&mentation"), m_pButtonBG);
     scopeLayout -> addWidget(m_pImplementationRB);
     topLayout -> addWidget(m_pButtonBG);
+
     //setup documentation
-    m_pDocGB = new QGroupBox(this);
+    m_pDocGB = new Q3GroupBox(this);
     QHBoxLayout * docLayout = new QHBoxLayout(m_pDocGB);
     docLayout -> setMargin(margin);
     m_pDocGB -> setTitle(i18n("Documentation"));
 
-    m_pDoc = new QMultiLineEdit(m_pDocGB);
+    m_pDoc = new Q3MultiLineEdit(m_pDocGB);
     docLayout -> addWidget(m_pDoc);
     topLayout -> addWidget(m_pDocGB);
 
@@ -201,42 +226,42 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(p
     m_pClassNameLE -> setText(o -> getName());
     m_pDoc-> setText(o -> getDoc());
     Uml::Visibility s = o -> getVisibility();
-    if(s == Uml::Visibility::Public)
+    if (s == Uml::Visibility::Public)
         m_pPublicRB->setChecked(true);
-    else if(s == Uml::Visibility::Private)
+    else if (s == Uml::Visibility::Private)
         m_pPrivateRB->setChecked(true);
-    else if(s == Uml::Visibility::Protected)
+    else if (s == Uml::Visibility::Protected)
           m_pProtectedRB->setChecked(true);
     else
         m_pImplementationRB -> setChecked(true);
 
     // manage stereotypes
-    m_pStereoTypeCB -> setDuplicatesEnabled(false);//only allow one of each type in box
+    m_pStereoTypeCB -> setDuplicatesEnabled(false);  // only allow one of each type in box
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
-    insertStereotype (QString("")); // an empty stereotype is the default
+    insertStereotype (QString(), 0);  // an empty stereotype is the default
     int defaultStereotype=0;
     bool foundDefaultStereotype = false;
-    for (UMLStereotypeListIt it(m_pUmldoc->getStereotypes()); it.current(); ++it) {
+    // start with 1 as first entry is blank string
+    int counter = 1;
+    foreach (UMLStereotype* ust, m_pUmldoc->getStereotypes()) {
         if (!foundDefaultStereotype) {
-            if ( m_pObject->getStereotype() == it.current()->getName()) {
+            if ( m_pObject->getStereotype() == ust->getName()) {
                 foundDefaultStereotype = true;
+                defaultStereotype = counter;
             }
-            defaultStereotype++;
         }
-        insertStereotype (it.current()->getName());
+        insertStereotype (ust->getName(), counter++);
     }
-    // lookup for a default stereotype, if the operation doesn't have one
-    if (foundDefaultStereotype)
-        m_pStereoTypeCB -> setCurrentItem(defaultStereotype);
-    else
-        m_pStereoTypeCB -> setCurrentItem(-1);
+
+    m_pStereoTypeCB -> setCurrentIndex(defaultStereotype);
 
     ///////////
-    m_pDoc->setWordWrap(QMultiLineEdit::WidgetWidth);
+    m_pDoc->setWordWrap(Q3MultiLineEdit::WidgetWidth);
     //////////
 }
 
-ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o) : QWidget(parent) {
+ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o) : QWidget(parent) 
+{
     m_pObject = 0;
     m_pInstanceWidget = 0;
     m_pWidget = o;
@@ -246,7 +271,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o) : QWidge
     //int t = o -> getBaseType();
     m_pUmldoc = d;
     setMinimumSize(310,330);
-    QGridLayout * topLayout = new QGridLayout(this, 2, 1);
+    QGridLayout * topLayout = new QGridLayout(this);
     topLayout -> setSpacing(6);
 
     //setup name
@@ -256,7 +281,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o) : QWidge
     m_pNameL -> setText(i18n("Class name:"));
     m_pNameLayout -> addWidget(m_pNameL, 0, 0);
 
-    m_pClassNameLE = new QLineEdit(this);
+    m_pClassNameLE = new KLineEdit(this);
     m_pClassNameLE -> setText(o -> getName());
     m_pNameLayout -> addWidget(m_pClassNameLE, 0, 1);
 
@@ -264,7 +289,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o) : QWidge
     m_pInstanceL -> setText(i18n("Instance name:"));
     m_pNameLayout -> addWidget(m_pInstanceL, 1, 0);
 
-    m_pInstanceLE = new QLineEdit(this);
+    m_pInstanceLE = new KLineEdit(this);
     m_pInstanceLE -> setText(o -> getInstanceName());
     m_pNameLayout -> addWidget(m_pInstanceLE, 1, 1);
     UMLView *view = UMLApp::app()->getCurrentView();
@@ -273,35 +298,36 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o) : QWidge
     m_pDrawActorCB -> setChecked( o -> getDrawAsActor() );
     m_pNameLayout -> addWidget( m_pDrawActorCB, 2, 0 );
 
-    if(view -> getType() == Uml::dt_Collaboration) {
+    if (view -> getType() == Uml::dt_Collaboration) {
         m_pMultiCB = new QCheckBox(i18n("Multiple instance"), this);
         m_pMultiCB -> setChecked(o -> getMultipleInstance());
         m_pNameLayout -> addWidget(m_pMultiCB, 2,1);
         if( m_pDrawActorCB -> isChecked() )
             m_pMultiCB -> setEnabled( false );
-    } else//sequence diagram
+    } else  //sequence diagram
     {
         m_pDeconCB = new QCheckBox(i18n("Show destruction"), this);
         m_pDeconCB->setChecked(o->getShowDestruction());
         m_pNameLayout -> addWidget(m_pDeconCB, 2,1);
     }
     //setup documentation
-    m_pDocGB = new QGroupBox(this);
+    m_pDocGB = new Q3GroupBox(this);
     topLayout -> addWidget(m_pDocGB, 1, 0);
     QHBoxLayout * docLayout = new QHBoxLayout(m_pDocGB);
     docLayout -> setMargin(margin);
     m_pDocGB -> setTitle(i18n("Documentation"));
 
-    m_pDoc = new QMultiLineEdit(m_pDocGB);
-    m_pDoc->setWordWrap(QMultiLineEdit::WidgetWidth);
+    m_pDoc = new Q3MultiLineEdit(m_pDocGB);
+    m_pDoc->setWordWrap(Q3MultiLineEdit::WidgetWidth);
     m_pDoc-> setText(o -> getDoc());
     docLayout -> addWidget(m_pDoc);
-    m_pObject = 0;//needs to be set to zero
-    if( m_pMultiCB )
+    m_pObject = 0;  //needs to be set to zero
+    if (m_pMultiCB)
         connect( m_pDrawActorCB, SIGNAL( toggled( bool ) ), this, SLOT( slotActorToggled( bool ) ) );
 }
 
-ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget) : QWidget(parent) {
+ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget) : QWidget(parent)
+{
     m_pWidget = 0;
     m_pObject = 0;
     m_pInstanceWidget = widget;
@@ -311,7 +337,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget) : QWid
     //int t = o -> getBaseType();
     m_pUmldoc = d;
     setMinimumSize(310,330);
-    QGridLayout* topLayout = new QGridLayout(this, 2, 1);
+    QGridLayout* topLayout = new QGridLayout(this);
     topLayout->setSpacing(6);
 
     //setup name
@@ -323,11 +349,11 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget) : QWid
     } else if (widget->getBaseType() == Uml::wt_Node) {
         m_pNameL->setText(i18n("Node name:"));
     } else {
-        kWarning() << "ClassGenPage called on unknown widget type" << endl;
+        uWarning() << "ClassGenPage called on unknown widget type";
     }
     m_pNameLayout->addWidget(m_pNameL, 0, 0);
 
-    m_pClassNameLE = new QLineEdit(this);
+    m_pClassNameLE = new KLineEdit(this);
     m_pClassNameLE->setText(widget->getName());
     m_pNameLayout->addWidget(m_pClassNameLE, 0, 1);
 
@@ -337,62 +363,82 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget) : QWid
     m_pStereoTypeCB = new KComboBox(true, this);
     m_pNameLayout->addWidget(m_pStereoTypeCB, 1, 1);
 
-    m_pStereoTypeCB->setCurrentText( widget->getUMLObject()->getStereotype() );
+    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), widget->getUMLObject()->getStereotype() );
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
 
     m_pInstanceL = new QLabel(this);
     m_pInstanceL->setText(i18n("Instance name:"));
     m_pNameLayout->addWidget(m_pInstanceL, 2, 0);
 
-    m_pInstanceLE = new QLineEdit(this);
+    m_pInstanceLE = new KLineEdit(this);
     m_pInstanceLE->setText(widget->getInstanceName());
     m_pNameLayout->addWidget(m_pInstanceLE, 2, 1);
 
     //setup documentation
-    m_pDocGB = new QGroupBox(this);
+    m_pDocGB = new Q3GroupBox(this);
     topLayout->addWidget(m_pDocGB, 1, 0);
     QHBoxLayout* docLayout = new QHBoxLayout(m_pDocGB);
     docLayout->setMargin(margin);
     m_pDocGB->setTitle(i18n("Documentation"));
 
-    m_pDoc = new QMultiLineEdit(m_pDocGB);
-    m_pDoc->setWordWrap(QMultiLineEdit::WidgetWidth);
+    m_pDoc = new Q3MultiLineEdit(m_pDocGB);
+    m_pDoc->setWordWrap(Q3MultiLineEdit::WidgetWidth);
     m_pDoc->setText(widget->getDoc());
     docLayout->addWidget(m_pDoc);
     m_pObject = 0;//needs to be set to zero
 }
 
-ClassGenPage::~ClassGenPage() {}
+ClassGenPage::~ClassGenPage() 
+{
+}
 
 void ClassGenPage::insertStereotype( const QString& type, int index )
 {
-    m_pStereoTypeCB->insertItem( type, index );
+    m_pStereoTypeCB->insertItem( index, type );
     m_pStereoTypeCB->completionObject()->addItem( type );
 }
 
-void ClassGenPage::updateObject() {
-    if(m_pObject) {
+void ClassGenPage::updateObject()
+{
+    if (m_pObject) {
         QString name = m_pClassNameLE -> text();
 
         m_pObject -> setDoc(m_pDoc -> text());
 
-        if(m_pStereoTypeCB)
+        if (m_pStereoTypeCB)
             m_pObject -> setStereotype(m_pStereoTypeCB->currentText());
-        /**
-         * @todo enable the package lineedit field amd add logic for changing the package
-        if(m_pPackageLE)
-            m_pObject -> setPackage(m_pPackageLE -> text());
-         */
-        if( m_pAbstractCB )
+
+        Uml::Object_Type t = m_pObject->getBaseType();
+        if (t == Uml::ot_Class || t == Uml::ot_Interface) {
+          QString packageName = m_pPackageCB->currentText().trimmed();
+          UMLObject* newPackage = NULL;
+
+          if ( !packageName.isEmpty()) {
+            if ( ( newPackage = m_pUmldoc->findUMLObject(packageName, Uml::ot_Package) ) == NULL )
+                newPackage = Import_Utils::createUMLObject(Uml::ot_Package, packageName);
+          } else {
+             newPackage = m_pUmldoc->getRootFolder( Uml::mt_Logical );
+          }
+
+          // adjust list view items
+          UMLListView *lv = UMLApp::app()->getListView();
+          UMLListViewItem *newLVParent = lv->findUMLObject(newPackage);
+          lv->moveObject(m_pObject->getID(),
+                         Model_Utils::convert_OT_LVT(m_pObject),
+                           newLVParent);
+        }
+
+        if ( m_pAbstractCB )
             m_pObject -> setAbstract( m_pAbstractCB -> isChecked() );
-        //make sure unique name
-        UMLObject *o = m_pUmldoc -> findUMLObject(name);
-        if(o && m_pObject != o) {
-            KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
-                               i18n("Name is Not Unique"), false);
-            m_pClassNameLE -> setText( m_pObject -> getName() );
-        } else
-            m_pObject -> setName(name);
+
+         //make sure unique name
+         UMLObject *o = m_pUmldoc -> findUMLObject(name);
+         if (o && m_pObject != o) {
+             KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
+                                i18n("Name is Not Unique"), false);
+             m_pClassNameLE -> setText( m_pObject -> getName() );
+         } else
+             m_pObject -> setName(name);
         Uml::Visibility s;
         if(m_pPublicRB -> isChecked())
           s = Uml::Visibility::Public;
@@ -423,18 +469,18 @@ void ClassGenPage::updateObject() {
         }
 
     }//end if m_pObject
-    else if(m_pWidget) {
+    else if (m_pWidget) {
         m_pWidget -> setInstanceName(m_pInstanceLE -> text());
-        if(m_pMultiCB)
+        if (m_pMultiCB)
             m_pWidget -> setMultipleInstance(m_pMultiCB -> isChecked());
         m_pWidget -> setDrawAsActor( m_pDrawActorCB -> isChecked() );
-        if( m_pDeconCB )
+        if (m_pDeconCB)
             m_pWidget -> setShowDestruction( m_pDeconCB -> isChecked() );
         QString name = m_pClassNameLE -> text();
         m_pWidget -> setDoc(m_pDoc -> text());
         UMLObject * o = m_pWidget -> getUMLObject();
         UMLObject * old = m_pUmldoc -> findUMLObject(name);
-        if(old && o != old) {
+        if (old && o != old) {
             KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
                                i18n("Name is Not Unique"), false);
         } else
@@ -445,7 +491,7 @@ void ClassGenPage::updateObject() {
         m_pInstanceWidget->setDoc(m_pDoc->text());
         UMLObject* o = m_pInstanceWidget->getUMLObject();
         UMLObject* old = m_pUmldoc->findUMLObject(name);
-        if(old && o != old) {
+        if (old && o != old) {
             KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
                                i18n("Name is Not Unique"), false);
         } else {
@@ -455,11 +501,10 @@ void ClassGenPage::updateObject() {
     }
 }
 
-void ClassGenPage::slotActorToggled( bool state ) {
-    if( m_pMultiCB )
+void ClassGenPage::slotActorToggled( bool state )
+{
+    if (m_pMultiCB)
         m_pMultiCB -> setEnabled( !state );
 }
 
-
-
 #include "classgenpage.moc"
