@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -13,65 +13,81 @@
 #include "umloperationdialog.h"
 
 //qt includes
-#include <qlayout.h>
-#include <qgroupbox.h>
-#include <qlistbox.h>
-#include <qbuttongroup.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
-#include <qlineedit.h>
+#include <QtGui/QLayout>
+#include <q3groupbox.h>
+#include <q3listbox.h>
+#include <q3buttongroup.h>
+#include <QtGui/QPushButton>
+#include <QtGui/QRadioButton>
+#include <QtGui/QLabel>
+#include <QtGui/QCheckBox>
+#include <QtGui/QVBoxLayout>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QGridLayout>
 
 //kde includes
+#include <klineedit.h>
 #include <kcombobox.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kbuttonbox.h>
+#include <kdialogbuttonbox.h>
 #include <karrowbutton.h>
 
 //app includes
-#include "../uml.h"
-#include "../umldoc.h"
-#include "../operation.h"
-#include "../classifier.h"
-#include "../template.h"
-#include "../listpopupmenu.h"
-#include "../umlattributelist.h"
-#include "../classifierlistitem.h"
-#include "../umlclassifierlistitemlist.h"
-#include "../dialog_utils.h"
+#include "uml.h"
+#include "umldoc.h"
+#include "operation.h"
+#include "classifier.h"
+#include "template.h"
+#include "listpopupmenu.h"
+#include "umlattributelist.h"
+#include "classifierlistitem.h"
+#include "umlclassifierlistitemlist.h"
+#include "dialog_utils.h"
 #include "parmpropdlg.h"
-#include "../stereotype.h"
-#include "../uniqueid.h"
+#include "stereotype.h"
+#include "uniqueid.h"
 
 UMLOperationDialog::UMLOperationDialog( QWidget * parent, UMLOperation * pOperation )
-        : KDialogBase( Plain, i18n("Operation Properties"), Help | Ok | Cancel , Ok, parent, "_UMLOPERATIONDLG_", true, true) {
+        : KDialog( parent) 
+{
+    setCaption( i18n("Operation Properties") );
+    setButtons( Help | Ok | Cancel );
+    setDefaultButton( Ok );
+    setModal( true );
+    showButtonSeparator( true );
+
     m_pOperation = pOperation;
     m_doc = UMLApp::app()->getDocument();
     m_pMenu = 0;
     setupDialog();
+    connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
+    connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
 }
 
-UMLOperationDialog::~UMLOperationDialog() {}
-
-void UMLOperationDialog::setupDialog() {
+UMLOperationDialog::~UMLOperationDialog()
+{
+}
 
+void UMLOperationDialog::setupDialog()
+{
+    QFrame *frame = new QFrame( this );
+    setMainWidget( frame );
     int margin = fontMetrics().height();
-    QVBoxLayout * topLayout = new QVBoxLayout( plainPage() );
+    QVBoxLayout * topLayout = new QVBoxLayout( frame );
 
-    m_pGenGB = new QGroupBox(i18n("General Properties"), plainPage() );
-    QGridLayout * genLayout = new QGridLayout(m_pGenGB, 3, 4 );
-    genLayout -> setColStretch(1, 1);
-    genLayout -> setColStretch(3, 1);
-    genLayout -> addColSpacing(1, 200);
-    genLayout -> addColSpacing(3, 200);
+    m_pGenGB = new Q3GroupBox(i18n("General Properties"), frame );
+    QGridLayout * genLayout = new QGridLayout(m_pGenGB);
+    genLayout -> setColumnStretch(1, 1);
+    genLayout -> setColumnStretch(3, 1);
+    genLayout -> addItem(new QSpacerItem(200, 0), 0, 1);
+    genLayout -> addItem(new QSpacerItem(200, 0), 0, 3);
     genLayout -> setMargin(margin);
     genLayout -> setSpacing(10);
 
     Dialog_Utils::makeLabeledEditField( m_pGenGB, genLayout, 0,
-                                    m_pNameL, i18n("&Name:"),
+                                    m_pNameL, i18nc("operation name", "&Name:"),
                                     m_pNameLE, m_pOperation->getName() );
 
     m_pRtypeL = new QLabel(i18n("&Type:"), m_pGenGB );
@@ -98,18 +114,18 @@ void UMLOperationDialog::setupDialog() {
 
     topLayout -> addWidget( m_pGenGB );
 
-    m_pScopeBG = new QButtonGroup(i18n("Visibility"), plainPage() );
+    m_pScopeBG = new Q3ButtonGroup(i18n("Visibility"), frame );
 
     QHBoxLayout * scopeLayout = new QHBoxLayout(m_pScopeBG);
     scopeLayout -> setMargin(margin);
 
-    m_pPublicRB = new QRadioButton(i18n("P&ublic"), m_pScopeBG);
+    m_pPublicRB = new QRadioButton(i18nc("public visibility", "P&ublic"), m_pScopeBG);
     scopeLayout -> addWidget(m_pPublicRB);
 
-    m_pPrivateRB = new QRadioButton(i18n("P&rivate"), m_pScopeBG);
+    m_pPrivateRB = new QRadioButton(i18nc("private visibility", "P&rivate"), m_pScopeBG);
     scopeLayout -> addWidget(m_pPrivateRB);
 
-    m_pProtectedRB = new QRadioButton(i18n("Prot&ected"), m_pScopeBG);
+    m_pProtectedRB = new QRadioButton(i18nc("protected visibility", "Prot&ected"), m_pScopeBG);
     scopeLayout -> addWidget(m_pProtectedRB);
 
     m_pImplementationRB = new QRadioButton(i18n("I&mplementation"), m_pScopeBG);
@@ -117,14 +133,14 @@ void UMLOperationDialog::setupDialog() {
 
     topLayout -> addWidget(m_pScopeBG);
 
-    m_pParmsGB = new QGroupBox(i18n("Parameters"), plainPage() );
+    m_pParmsGB = new Q3GroupBox(i18n("Parameters"), frame );
     QVBoxLayout* parmsLayout = new QVBoxLayout(m_pParmsGB);
     parmsLayout->setMargin(margin);
     parmsLayout->setSpacing(10);
 
     //horizontal box contains the list box and the move up/down buttons
     QHBoxLayout* parmsHBoxLayout = new QHBoxLayout(parmsLayout);
-    m_pParmsLB = new QListBox(m_pParmsGB);
+    m_pParmsLB = new Q3ListBox(m_pParmsGB);
     parmsHBoxLayout->addWidget(m_pParmsLB);
 
     //the move up/down buttons (another vertical box)
@@ -137,11 +153,13 @@ void UMLOperationDialog::setupDialog() {
     m_pDownButton->setEnabled( false );
     buttonLayout->addWidget( m_pDownButton );
 
-    KButtonBox* buttonBox = new KButtonBox(m_pParmsGB);
-    buttonBox->addButton( i18n("Ne&w Parameter..."), this, SLOT(slotNewParameter()) );
-    m_pDeleteButton = buttonBox->addButton( i18n("&Delete"), this, SLOT(slotDeleteParameter()) );
-    m_pPropertiesButton = buttonBox->addButton( i18n("&Properties"), this,
-                          SLOT(slotParameterProperties()) );
+    KDialogButtonBox* buttonBox = new KDialogButtonBox(m_pParmsGB);
+    buttonBox->addButton( i18n("Ne&w Parameter..."), KDialogButtonBox::ActionRole,
+                          this, SLOT(slotNewParameter()) );
+    m_pDeleteButton = buttonBox->addButton( i18n("&Delete"), KDialogButtonBox::ActionRole,
+                                            this, SLOT(slotDeleteParameter()) );
+    m_pPropertiesButton = buttonBox->addButton( i18n("&Properties"), KDialogButtonBox::ActionRole,
+                          this, SLOT(slotParameterProperties()) );
     parmsLayout->addWidget(buttonBox);
 
     topLayout -> addWidget(m_pParmsGB);
@@ -165,13 +183,13 @@ void UMLOperationDialog::setupDialog() {
     UMLClassifier *classifier = dynamic_cast<UMLClassifier*>(m_pOperation->parent());
     if (classifier) {
         UMLClassifierListItemList tmplParams( classifier->getFilteredList(Uml::ot_Template) );
-        for (UMLClassifierListItem *li = tmplParams.first(); li; li = tmplParams.next())
+        foreach (UMLClassifierListItem* li, tmplParams ) {
             insertType( li->getName() );
+        }
     }
     //now add the Classes and Interfaces (both are Concepts)
     UMLClassifierList namesList( m_doc->getConcepts() );
-    UMLClassifier* pConcept = 0;
-    for(pConcept=namesList.first(); pConcept!=0 ;pConcept=namesList.next()) {
+    foreach (UMLClassifier* pConcept, namesList) {
         insertType( pConcept->getFullyQualifiedName() );
     }
 
@@ -179,10 +197,10 @@ void UMLOperationDialog::setupDialog() {
     int returnBoxCount = 0;
     bool foundReturnType = false;
     while (returnBoxCount < m_pRtypeCB->count() && foundReturnType == false) {
-        QString returnBoxString = m_pRtypeCB->text(returnBoxCount);
+        QString returnBoxString = m_pRtypeCB->itemText(returnBoxCount);
         if ( returnBoxString == m_pOperation->getTypeName() ) {
             foundReturnType = true;
-            m_pRtypeCB->setCurrentItem(returnBoxCount);
+            m_pRtypeCB->setCurrentIndex(returnBoxCount);
             break;
         }
         returnBoxCount++;
@@ -190,14 +208,14 @@ void UMLOperationDialog::setupDialog() {
 
     if (!foundReturnType) {
         insertType( m_pOperation->getTypeName(), 0 );
-        m_pRtypeCB->setCurrentItem(0);
+        m_pRtypeCB->setCurrentIndex(0);
     }
 
     //fill in parm list box
     UMLAttributeList list = m_pOperation->getParmList();
-    UMLAttribute * pAtt = 0;
-    for (pAtt = list.first(); pAtt; pAtt = list.next())
+    foreach (UMLAttribute* pAtt, list ) {
         m_pParmsLB->insertItem( pAtt->getName() );
+    }
 
     //set scope
     Uml::Visibility scope = m_pOperation -> getVisibility();
@@ -213,90 +231,97 @@ void UMLOperationDialog::setupDialog() {
     // manage stereotypes
     m_pStereoTypeCB -> setDuplicatesEnabled(false);//only allow one of each type in box
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
-    insertStereotype (QString("")); // an empty stereotype is the default
+    insertStereotype (QString()); // an empty stereotype is the default
     int defaultStereotype=0;
     bool foundDefaultStereotype = false;
-    for (UMLStereotypeListIt it(m_doc->getStereotypes()); it.current(); ++it) {
+    foreach (UMLStereotype* currentSt, m_doc->getStereotypes() ) {
         if (!foundDefaultStereotype) {
-            if ( m_pOperation->getStereotype() == it.current()->getName()) {
+            if ( m_pOperation->getStereotype() == currentSt->getName()) {
                 foundDefaultStereotype = true;
             }
             defaultStereotype++;
         }
-        insertStereotype (it.current()->getName());
+        insertStereotype (currentSt->getName());
     }
     // lookup for a default stereotype, if the operation doesn't have one
     if (foundDefaultStereotype)
-        m_pStereoTypeCB->setCurrentItem(defaultStereotype);
+        m_pStereoTypeCB->setCurrentIndex(defaultStereotype);
     else
-        m_pStereoTypeCB->setCurrentItem(-1);
+        m_pStereoTypeCB->setCurrentIndex(-1);
 
     //setup parm list box signals
     connect( m_pUpButton, SIGNAL( clicked() ), this, SLOT( slotParameterUp() ) );
     connect( m_pDownButton, SIGNAL( clicked() ), this, SLOT( slotParameterDown() ) );
 
-    connect(m_pParmsLB, SIGNAL(clicked(QListBoxItem*)),
-            this, SLOT(slotParamsBoxClicked(QListBoxItem*)));
+    connect(m_pParmsLB, SIGNAL(clicked(Q3ListBoxItem*)),
+            this, SLOT(slotParamsBoxClicked(Q3ListBoxItem*)));
 
-    connect(m_pParmsLB, SIGNAL(rightButtonPressed(QListBoxItem *, const QPoint &)),
-            this, SLOT(slotParmRightButtonPressed(QListBoxItem *, const QPoint &)));
+    connect(m_pParmsLB, SIGNAL(rightButtonPressed(Q3ListBoxItem *, const QPoint &)),
+            this, SLOT(slotParmRightButtonPressed(Q3ListBoxItem *, const QPoint &)));
 
-    connect(m_pParmsLB, SIGNAL(rightButtonClicked(QListBoxItem *, const QPoint &)),
-            this, SLOT(slotParmRightButtonClicked(QListBoxItem *, const QPoint &)));
+    connect(m_pParmsLB, SIGNAL(rightButtonClicked(Q3ListBoxItem *, const QPoint &)),
+            this, SLOT(slotParmRightButtonClicked(Q3ListBoxItem *, const QPoint &)));
 
-
-    connect(m_pParmsLB, SIGNAL(doubleClicked(QListBoxItem *)),
-            this, SLOT(slotParmDoubleClick(QListBoxItem *)));
+    connect(m_pParmsLB, SIGNAL(doubleClicked(Q3ListBoxItem *)),
+            this, SLOT(slotParmDoubleClick(Q3ListBoxItem *)));
 
     m_pNameLE->setFocus();
     connect( m_pNameLE, SIGNAL( textChanged ( const QString & ) ), SLOT( slotNameChanged( const QString & ) ) );
-    slotNameChanged(m_pNameLE->text() );
-
+    slotNameChanged( m_pNameLE->text() );
 }
 
 void UMLOperationDialog::slotNameChanged( const QString &_text )
 {
-    enableButtonOK( !_text.isEmpty() );
+    enableButtonOk( !_text.isEmpty() );
 }
 
-
-void UMLOperationDialog::slotParmRightButtonPressed(QListBoxItem *item, const QPoint &p) {
+void UMLOperationDialog::slotParmRightButtonPressed(Q3ListBoxItem *item, const QPoint &p)
+{
     ListPopupMenu::Menu_Type type = ListPopupMenu::mt_Undefined;
-    if(item)//pressed on an item
+    if (item)//pressed on an item
     {
         type = ListPopupMenu::mt_Parameter_Selected;
     } else//pressed into fresh air
     {
         type = ListPopupMenu::mt_New_Parameter;
     }
-    if(m_pMenu) {
+    if (m_pMenu) {
         m_pMenu -> hide();
-        disconnect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotParmPopupMenuSel(int)));
+        disconnect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotParmPopupMenuSel(QAction*)));
         delete m_pMenu;
         m_pMenu = 0;
     }
     m_pMenu = new ListPopupMenu(this, type);
     m_pMenu->popup(p);
-    connect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotParmPopupMenuSel(int)));
-
+    connect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotParmPopupMenuSel(QAction*)));
 }
 
-void UMLOperationDialog::slotParmRightButtonClicked(QListBoxItem */*item*/, const QPoint &/*p*/) {
-    if(m_pMenu) {
+void UMLOperationDialog::slotParmRightButtonClicked(Q3ListBoxItem *item, const QPoint &p)
+{
+    Q_UNUSED(item)
+    Q_UNUSED(p)
+
+    if (m_pMenu) {
         m_pMenu -> hide();
-        disconnect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotParmPopupMenuSel(int)));
+        disconnect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotParmPopupMenuSel(QAction*)));
         delete m_pMenu;
         m_pMenu = 0;
     }
 }
 
-void UMLOperationDialog::slotParmDoubleClick(QListBoxItem *item) {
-    if(!item)
+void UMLOperationDialog::slotParmDoubleClick(Q3ListBoxItem *item)
+{
+    if (!item)
         return;
-    slotParmPopupMenuSel(ListPopupMenu::mt_Properties);
+    if (m_pMenu) {
+        QAction* action = m_pMenu->getAction(ListPopupMenu::mt_Properties);
+        slotParmPopupMenuSel(action);
+    }
 }
 
-void UMLOperationDialog::slotParmPopupMenuSel(int id) {
+void UMLOperationDialog::slotParmPopupMenuSel(QAction* action)
+{
+    ListPopupMenu::Menu_Type id = m_pMenu->getMenuType(action);
     if( id == ListPopupMenu::mt_Rename || id == ListPopupMenu::mt_Properties ) {
         slotParameterProperties();
     } else if( id == ListPopupMenu::mt_New_Parameter ) {
@@ -307,7 +332,8 @@ void UMLOperationDialog::slotParmPopupMenuSel(int id) {
     }
 }
 
-void UMLOperationDialog::slotNewParameter() {
+void UMLOperationDialog::slotNewParameter()
+{
     int result = 0;
     UMLAttribute* pAtt = 0;
 
@@ -318,14 +344,14 @@ void UMLOperationDialog::slotNewParameter() {
     result = dlg.exec();
     QString name = dlg.getName();
     pAtt = m_pOperation -> findParm( name );
-    if( result ) {
-        if( name.length() == 0 ) {
+    if ( result ) {
+        if ( name.length() == 0 ) {
             KMessageBox::error(this, i18n("You have entered an invalid parameter name."),
                                i18n("Parameter Name Invalid"), false);
             delete newAttribute;
             return;
         }
-        if( !pAtt ) {
+        if ( !pAtt ) {
             newAttribute->setID( UniqueID::gen() );
             newAttribute->setName( name );
             newAttribute->setTypeName( dlg.getTypeName() );
@@ -345,7 +371,8 @@ void UMLOperationDialog::slotNewParameter() {
     }
 }
 
-void UMLOperationDialog::slotDeleteParameter() {
+void UMLOperationDialog::slotDeleteParameter()
+{
     UMLAttribute* pOldAtt = m_pOperation->findParm( m_pParmsLB->currentText() );
 
     m_pOperation->removeParm( pOldAtt );
@@ -358,21 +385,22 @@ void UMLOperationDialog::slotDeleteParameter() {
     m_pDownButton->setEnabled(false);
 }
 
-void UMLOperationDialog::slotParameterProperties() {
+void UMLOperationDialog::slotParameterProperties()
+{
     int result = 0;
     UMLAttribute* pAtt = 0, * pOldAtt = 0;
     pOldAtt = m_pOperation->findParm( m_pParmsLB->currentText() );
 
-    if( !pOldAtt ) {
-        kDebug() << "THE impossible has occurred for:" << m_pParmsLB->currentText() << endl;
+    if ( !pOldAtt ) {
+        uDebug() << "THE impossible has occurred for:" << m_pParmsLB->currentText();
         return;
     }//should never occur
     ParmPropDlg dlg(this, m_doc, pOldAtt);
     result = dlg.exec();
     QString name = dlg.getName();
     pAtt = m_pOperation->findParm( name );
-    if( result ) {
-        if( name.length() == 0 ) {
+    if ( result ) {
+        if ( name.length() == 0 ) {
             KMessageBox::error(this, i18n("You have entered an invalid parameter name."),
                                i18n("Parameter Name Invalid"), false);
             return;
@@ -384,17 +412,17 @@ void UMLOperationDialog::slotParameterProperties() {
             QString typeName = dlg.getTypeName();
             if (pOldAtt->getTypeName() != typeName) {
                 UMLClassifierList namesList( m_doc->getConcepts() );
-                UMLClassifier* obj = NULL;
-                for (obj=namesList.first(); obj!=0; obj=namesList.next()) {
+                bool breakFlag = false;
+                foreach ( UMLObject* obj, namesList) {
                     if (typeName == obj->getFullyQualifiedName()) {
                         pOldAtt->setType( obj );
+                        breakFlag = true;
                         break;
                     }
                 }
-                if (obj == NULL) {
+                if (!breakFlag) {
                     // Nothing found: set type name directly. Bad.
-                    kDebug() << "UMLOperationDialog::slotParameterProperties: "
-                    << typeName << " not found." << endl;
+                    uDebug() << typeName << " not found." << endl;
                     pOldAtt->setTypeName( typeName );  // Bad.
                 }
             }
@@ -411,7 +439,7 @@ void UMLOperationDialog::slotParameterProperties() {
 
 void UMLOperationDialog::slotParameterUp()
 {
-    kDebug() << k_funcinfo << endl;
+    uDebug();
     UMLAttribute* pOldAtt = m_pOperation->findParm( m_pParmsLB->currentText() );
 
     m_pOperation->moveParmLeft( pOldAtt );
@@ -435,7 +463,8 @@ void UMLOperationDialog::slotParameterDown()
     slotParamsBoxClicked( m_pParmsLB->selectedItem() );
 }
 
-void UMLOperationDialog::slotParamsBoxClicked(QListBoxItem* parameterItem) {
+void UMLOperationDialog::slotParamsBoxClicked(Q3ListBoxItem* parameterItem)
+{
     if (parameterItem) {
         m_pDeleteButton->setEnabled(true);
         m_pPropertiesButton->setEnabled(true);
@@ -463,9 +492,9 @@ bool UMLOperationDialog::apply()
     if( classifier != 0L &&
             classifier->checkOperationSignature(name, m_pOperation->getParmList(), m_pOperation) )
     {
-        QString msg = QString(i18n("An operation with that signature already exists in %1.\n")).arg(classifier->getName())
+        QString msg = i18n("An operation with that signature already exists in %1.\n", classifier->getName())
                       +
-                      QString(i18n("Choose a different name or parameter list." ));
+                      i18n("Choose a different name or parameter list.");
         KMessageBox::error(this, msg, i18n("Operation Name Invalid"), false);
         return false;
     }
@@ -505,11 +534,13 @@ bool UMLOperationDialog::apply()
     return true;
 }
 
-void UMLOperationDialog::slotApply() {
+void UMLOperationDialog::slotApply()
+{
     apply();
 }
 
-void UMLOperationDialog::slotOk() {
+void UMLOperationDialog::slotOk() 
+{
     if ( apply() ) {
         accept();
     }
@@ -517,13 +548,13 @@ void UMLOperationDialog::slotOk() {
 
 void UMLOperationDialog::insertType( const QString& type, int index )
 {
-    m_pRtypeCB->insertItem( type, index );
+    m_pRtypeCB->insertItem( index, type );
     m_pRtypeCB->completionObject()->addItem( type );
 }
 
 void UMLOperationDialog::insertStereotype( const QString& type, int index )
 {
-    m_pStereoTypeCB->insertItem( type, index );
+    m_pStereoTypeCB->insertItem( index, type );
     m_pStereoTypeCB->completionObject()->addItem( type );
 }
 
