@@ -1,8 +1,3 @@
-/***************************************************************************
-                          refactoringassistant.h
-                             -------------------
-    copyright            : (C) 2003 Luis De la Parra
- ***************************************************************************/
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,15 +5,18 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003 Luis De la Parra <lparrab@gmx.net>                 *
+ *   copyright (C) 2004-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
-
 #ifndef REFACTORING_ASSISTANT
 #define REFACTORING_ASSISTANT
 
-
-#include <klistview.h>
-#include <qpixmap.h>
+#include <k3listview.h>
+#include <QtGui/QPixmap>
+#include <QtGui/QMenu>
+#include <QtGui/QDropEvent>
 #include <map>
 
 
@@ -27,16 +25,15 @@ class UMLClassifier;
 class UMLClassifierListItem;
 class UMLDoc;
 
-class QPopupMenu;
 class QPoint;
 
-class RefactoringAssistant : public KListView
+class RefactoringAssistant : public K3ListView
 {
     Q_OBJECT
 public:
-    typedef std::map<QListViewItem*, UMLObject*> UMLObjectMap;
+    typedef std::map<Q3ListViewItem*, UMLObject*> UMLObjectMap;
 
-    RefactoringAssistant( UMLDoc *doc, UMLClassifier *obj = 0, QWidget *parent = 0, const char *name = 0 );
+    explicit RefactoringAssistant( UMLDoc *doc, UMLClassifier *obj = 0, QWidget *parent = 0, const char *name = 0 );
     virtual ~RefactoringAssistant();
 
     void refactor( UMLClassifier *obj );
@@ -58,31 +55,36 @@ public slots:
     void attributeAdded( UMLClassifierListItem *a );
     void attributeRemoved( UMLClassifierListItem *a );
 
-    void itemExecuted( QListViewItem *item );
-    void showContextMenu( KListView*, QListViewItem*, const QPoint&);
+    void itemExecuted( Q3ListViewItem *item );
+    void showContextMenu( K3ListView*, Q3ListViewItem*, const QPoint&);
 
 protected:
+
     struct { QPixmap Public,
         Protected,
         Private,
-             Implementation,
+        Implementation,
         Generalization,
         Subclass;
     } m_pixmaps;
 
-    UMLObject* findUMLObject( const QListViewItem* );
-    QListViewItem* findListViewItem( const UMLObject *obj );
+    UMLObject* findUMLObject( const Q3ListViewItem* );
+    Q3ListViewItem* findListViewItem( const UMLObject *obj );
     void editProperties( UMLObject *obj );
-    void addClassifier( UMLClassifier *classifier, QListViewItem *parent = 0, bool addSuper = true, bool addSub = true, bool recurse = false );
+    void addClassifier( UMLClassifier *classifier, Q3ListViewItem *parent = 0, bool addSuper = true, bool addSub = true, bool recurse = false );
     void loadPixmaps();
     virtual bool acceptDrag(QDropEvent *event) const;
-    virtual void movableDropEvent (QListViewItem* parent, QListViewItem* afterme);
-    void setVisibilityIcon( QListViewItem *item , const UMLObject *obj );
+    virtual void movableDropEvent (Q3ListViewItem* parent, Q3ListViewItem* afterme);
+    void setVisibilityIcon( Q3ListViewItem *item , const UMLObject *obj );
+
     UMLClassifier *m_umlObject;
     UMLDoc *m_doc;
-    QPopupMenu *m_menu;
+    QMenu *m_menu;
     UMLObjectMap m_umlObjectMap;
 
+private:
+
+    QAction* createAction(const QString text, const char * method);
 
 };
 
